==> yorkr_0.0.5.tar.gz: yorkr/README.md <==
# yorkr
This R package can be used to analyze performances of cricketers based on match data from [Cricsheet](http://www.cricsheet.org). The yorkr package can handle match data from ODIs, Twenty20s and IPL T20s from Cricsheet. The data has to be in yaml format

The package can be installed directly from CRAN as follows

install.packages("yorkr")
library(yorkr)

The latest updates can be installed directly from Github
library(devtools)
install_github("tvganesh/yorkr")
library(yorkr)

For details on how to use the yorkr package please see my posts

1. [Introducing cricket package yorkr-Part1:Beaten by sheer pace!](https://gigadom.wordpress.com/2016/04/02/introducing-cricket-package-yorkr-part-1-beaten-by-sheer-pace/). 
2. [Introducing cricket package yorkr: Part 2-Trapped leg before wicket!](https://gigadom.wordpress.com/2016/04/03/introducing-cricket-package-yorkr-part-2-trapped-leg-before-wicket/)
3. [Introducing cricket package yorkr: Part 3-Foxed by flight!](https://gigadom.wordpress.com/2016/04/07/introducing-cricket-package-yorkr-part-3-foxed-by-flight/)
4. [Introducing cricket package yorkr:Part 4-In the block hole!](https://gigadom.wordpress.com/2016/04/12/introducing-cricket-package-yorkrpart-4-in-the-block-hole/)
5. [yorkr pads up for the Twenty20s: Part 1- Analyzing team"s match performance](https://gigadom.wordpress.com/2016/04/16/yorkr-pads-up-for-the-twenty20s-part-1-analyzing-teams-match-performance/). 
6. [yorkr pads up for the Twenty20s: Part 2-Head to head confrontation between teams](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-the-twenty20s-part-2-head-to-head-confrontation-between-teams/)
7. [yorkr pads up for the Twenty20s:Part 3:Overall team performance against all oppositions!](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-the-twenty20spart-3overall-team-performance-against-all-oppositions/)
8. [yorkr pads up for Twenty20s:Part 4- Individual batting and bowling performances!](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-twenty20spart-4-individual-batting-and-bowling-performances/)
9. [yorkr crashes the IPL party ! – Part 1](https://gigadom.wordpress.com/2016/04/19/yorkr-crashes-the-ipl-party-part-1/)
10. [yorkr crashes the IPL party ! – Part 2](https://gigadom.wordpress.com/2016/04/20/yorkr-crashes-the-ipl-party-part-2/)
11. [yorkr crashes the IPL party ! – Part 3](https://gigadom.wordpress.com/2016/04/21/yorkr-crashes-the-ipl-party-part-3/)
12. [yorkr crashes the IPL party! – Part 4](https://gigadom.wordpress.com/2016/04/22/yorkr-crashes-the-ipl-party-part-4/)

==> yorkr_0.0.7.tar.gz: yorkr/README.md <==

#### Package downloads from the [RStudio CRAN Mirror](http://cran-logs.rstudio.com/)</b>

This month      | In total
--------------- | -----------
![month](http://cranlogs.r-pkg.org/badges/yorkr) | ![total](http://cranlogs.r-pkg.org/badges/grand-total/yorkr)

<hr>

# yorkr
This R package can be used to analyze performances of cricketers based on match data from [Cricsheet](http://www.cricsheet.org). The yorkr package can handle match data from ODIs, Twenty20s and IPL T20s from Cricsheet. The data has to be in yaml format

The package can be installed directly from CRAN as follows

install.packages("yorkr")
library(yorkr)

The latest updates can be installed directly from Github
library(devtools)
install_github("tvganesh/yorkr")
library(yorkr)

For details on how to use the yorkr package please see my posts

1. [Introducing cricket package yorkr-Part1:Beaten by sheer pace!](https://gigadom.wordpress.com/2016/04/02/introducing-cricket-package-yorkr-part-1-beaten-by-sheer-pace/). 
2. [Introducing cricket package yorkr: Part 2-Trapped leg before wicket!](https://gigadom.wordpress.com/2016/04/03/introducing-cricket-package-yorkr-part-2-trapped-leg-before-wicket/)
3. [Introducing cricket package yorkr: Part 3-Foxed by flight!](https://gigadom.wordpress.com/2016/04/07/introducing-cricket-package-yorkr-part-3-foxed-by-flight/)
4. [Introducing cricket package yorkr:Part 4-In the block hole!](https://gigadom.wordpress.com/2016/04/12/introducing-cricket-package-yorkrpart-4-in-the-block-hole/)
5. [yorkr pads up for the Twenty20s: Part 1- Analyzing team"s match performance](https://gigadom.wordpress.com/2016/04/16/yorkr-pads-up-for-the-twenty20s-part-1-analyzing-teams-match-performance/). 
6. [yorkr pads up for the Twenty20s: Part 2-Head to head confrontation between teams](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-the-twenty20s-part-2-head-to-head-confrontation-between-teams/)
7. [yorkr pads up for the Twenty20s:Part 3:Overall team performance against all oppositions!](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-the-twenty20spart-3overall-team-performance-against-all-oppositions/)
8. [yorkr pads up for Twenty20s:Part 4- Individual batting and bowling performances!](https://gigadom.wordpress.com/2016/04/17/yorkr-pads-up-for-twenty20spart-4-individual-batting-and-bowling-performances/)
9. [yorkr crashes the IPL party ! – Part 1](https://gigadom.wordpress.com/2016/04/19/yorkr-crashes-the-ipl-party-part-1/)
10. [yorkr crashes the IPL party ! – Part 2](https://gigadom.wordpress.com/2016/04/20/yorkr-crashes-the-ipl-party-part-2/)
11. [yorkr crashes the IPL party ! – Part 3](https://gigadom.wordpress.com/2016/04/21/yorkr-crashes-the-ipl-party-part-3/)
12. [yorkr crashes the IPL party! – Part 4](https://gigadom.wordpress.com/2016/04/22/yorkr-crashes-the-ipl-party-part-4/)
